@@ -10,7 +10,7 @@ An easy to use HTTP client based on httplib.
 :license: BSD 2-clause License, see LICENSE for more details.
 """
 
-__version__ = "1.2.1"
+__version__ = "1.2.2"
 __author__ = "Yue Du <ifduyue@gmail.com>"
 __url__ = "https://github.com/ifduyue/urlfetch"
 __license__ = "BSD 2-Clause License"
@@ -712,7 +712,7 @@ def request(
     ):
         via_proxy = True
         if "://" not in proxy:
-            proxy = "%s://%s" % (scheme, proxy)
+            proxy = "%s://%s" % ('http', proxy)
         parsed_proxy = parse_url(proxy)
         # Proxy-Authorization
         if parsed_proxy["username"] and parsed_proxy["password"]:
@@ -720,7 +720,7 @@ def request(
             proxyauth = base64.b64encode(proxyauth.encode("utf-8"))
             reqheaders["Proxy-Authorization"] = "Basic " + proxyauth.decode("utf-8")
         conn = make_connection(
-            scheme, parsed_proxy["host"], parsed_proxy["port"], timeout, source_address
+            parsed_proxy["scheme"], parsed_proxy["host"], parsed_proxy["port"], timeout, source_address
         )
     else:
         conn = make_connection(
@@ -799,7 +799,7 @@ def request(
         if proxy and parsed_url["host"] not in PROXY_IGNORE_HOSTS:
             via_proxy = True
             if "://" not in proxy:
-                proxy = "%s://%s" % (parsed_url["scheme"], proxy)
+                proxy = "%s://%s" % ('http', proxy)
             parsed_proxy = parse_url(proxy)
             # Proxy-Authorization
             if parsed_proxy["username"] and parsed_proxy["password"]:
@@ -810,7 +810,7 @@ def request(
                 proxyauth = base64.b64encode(proxyauth.encode("utf-8"))
                 reqheaders["Proxy-Authorization"] = "Basic " + proxyauth.decode("utf-8")
             conn = make_connection(
-                scheme,
+                parsed_proxy["scheme"],
                 parsed_proxy["host"],
                 parsed_proxy["port"],
                 timeout,
